@@ -1,65 +1,25 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: FontFile.pm,v 2.1 2007/01/04 17:39:40 areibens Exp $
-#
-#=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType::FontFile;
 
-BEGIN {
+our $VERSION = '2.028'; # VERSION
 
-    use utf8;
-    use Encode qw(:all);
-    use PDF::API2::Util;
-    use PDF::API2::IOString;
+use base 'PDF::API2::Basic::PDF::Dict';
 
-    use PDF::API2::Basic::PDF::Utils;
-    use PDF::API2::Basic::PDF::Dict;
-    use PDF::API2::Basic::TTF::Font;
-    use Data::Dumper;
-    use POSIX;
+use Encode qw(:all);
+use Font::TTF::Font;
+use POSIX qw(ceil floor);
 
-    use vars qw( @ISA $VERSION $cmap );
+use PDF::API2::Util;
+use PDF::API2::Basic::PDF::Utils;
 
-    @ISA = qw( PDF::API2::Basic::PDF::Dict );
-
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/01/04 17:39:40 $
-    $cmap={};
-}
 no warnings qw[ recursion uninitialized ];
 
+our $cmap = {};
 
 sub _look_for_cmap ($) {
     my $fname=lc(shift);
     $fname=~s/[^a-z0-9]+//gi;
     return({%{$cmap->{$fname}}}) if(defined $cmap->{$fname});
-    eval "require PDF::API2::Resource::CIDFont::CMap::$fname; ";
+    eval "require \"PDF/API2/Resource/CIDFont/CMap/$fname.cmap\"";
     unless($@){
         return({%{$cmap->{$fname}}});
     } else {
@@ -386,7 +346,6 @@ sub read_kern_table
             read($fh, $buf, $len);
         }
     }
-    ##print Dumper($data);
     return($data);
 }
 
@@ -463,7 +422,7 @@ sub new {
     my $data={};
 
     die "cannot find font '$file' ..." unless(-f $file);
-    my $font=PDF::API2::Basic::TTF::Font->open($file);
+    my $font=Font::TTF::Font->open($file);
     $data->{obj}=$font;
 
     $class = ref $class if ref $class;
@@ -473,9 +432,10 @@ sub new {
     $self->{' font'}=$font;
     $self->{' data'}=$data;
 
+	$data->{noembed} = $opts{-noembed}==1 ? 1 : 0;
     $data->{iscff} = (defined $font->{'CFF '}) ? 1 : 0;
 
-    $self->{Subtype}=PDFName('Type1C') if($data->{iscff});
+    $self->{Subtype}=PDFName('CIDFontType0C') if($data->{iscff});
 
     $data->{fontfamily}=$font->{'name'}->read->find_name(1);
     $data->{fontname}=$font->{'name'}->read->find_name(4);
@@ -505,7 +465,7 @@ sub new {
     }
     
     $data->{apiname}=$data->{fontname};
-    $data->{apiname}=~s/[^A-Za-z0-9]+/ /og;
+	$data->{apiname}=~s/[^A-Za-z0-9]+/ /og;
     $data->{apiname}=join('',map { $_=~s/[^A-Za-z0-9]+//og; $_=ucfirst(lc(substr($_,0,2))); $_; } split(/\s+/,$data->{apiname}));
     $data->{fontname}=~s/[\x00-\x1f\s]//og;
 
@@ -637,11 +597,13 @@ sub new {
     $data->{kern}=read_kern_table($font,$data->{upem},$self);
     delete $data->{kern} unless(defined $data->{kern});
 
-    $data->{fontname}=~s/[^a-zA-Z0-9]//og;
-    $data->{fontfamily}=~s/[^a-zA-Z0-9]//og;
-    $data->{apiname}=~s/[^a-zA-Z0-9]//og;
-    $data->{altname}=~s/[^a-zA-Z0-9]//og;
-    $data->{subname}=~s/[^a-zA-Z0-9]//og;
+    $data->{fontname}=~s/\s+//og;
+    $data->{fontfamily}=~s/\s+//og;
+    $data->{apiname}=~s/\s+//og;
+    $data->{altname}=~s/\s+//og;
+    $data->{subname}=~s/\s+//og;
+
+    $self->subsetByCId(0);
     
     return($self,$data);
 }
@@ -684,8 +646,6 @@ sub glyphNum { return ( $_[0]->font->{'maxp'}->read->{'numGlyphs'} ); }
 sub outobjdeep {
     my ($self, $fh, $pdf, %opts) = @_;
 
-    return $self->SUPER::outobjdeep($fh, $pdf) if defined $opts{'passthru'};
-
     my $f = $self->font;
 
     if($self->iscff) {
@@ -701,10 +661,16 @@ sub outobjdeep {
             }
         }
 
-        $self->{' stream'} = "";
-        my $ffh = PDF::API2::IOString->new(\$self->{' stream'});
-        $f->out($ffh, 'cmap', 'cvt ', 'fpgm', 'glyf', 'head', 'hhea', 'hmtx', 'loca', 'maxp', 'prep');
-        $self->{'Length1'}=PDFNum(length($self->{' stream'}));
+		if($self->data->{noembed} != 1)
+		{
+        	$self->{' stream'} = "";
+        	my $ffh;
+        	CORE::open($ffh, '+>', \$self->{' stream'});
+        	binmode($ffh,':raw');
+        	$f->out($ffh, 'cmap', 'cvt ', 'fpgm', 'glyf', 'head', 'hhea', 'hmtx', 'loca', 'maxp', 'prep');
+        	$self->{'Length1'}=PDFNum(length($self->{' stream'}));
+        	CORE::close($ffh);
+		}
     }
 
     $self->SUPER::outobjdeep($fh, $pdf, %opts);
@@ -712,90 +678,3 @@ sub outobjdeep {
 
 
 1;
-
-__END__
-
-=head1 AUTHOR
-
-alfred reibenschuh
-
-=head1 HISTORY
-
-    $Log: FontFile.pm,v $
-    Revision 2.1  2007/01/04 17:39:40  areibens
-    fixed [rt.cpan.org #24203] Incompatibility in Wide character handling
-
-    Revision 2.0  2005/11/16 02:18:14  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:50  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:26  areibens
-    genesis
-
-    Revision 1.20  2005/11/02 18:21:29  fredo
-    added kerning lookup strategy
-
-    Revision 1.19  2005/10/22 19:56:55  fredo
-    added mor agressive kerning strategy
-
-    Revision 1.18  2005/10/20 21:05:14  fredo
-    added handling of optional kerning
-
-    Revision 1.17  2005/09/12 16:52:59  fredo
-    added -isocmap option; fixed cmap handling for fallback entries
-
-    Revision 1.16  2005/06/17 19:44:03  fredo
-    fixed CPAN modulefile versioning (again)
-
-    Revision 1.15  2005/06/17 18:53:34  fredo
-    fixed CPAN modulefile versioning (dislikes cvs)
-
-    Revision 1.14  2005/03/20 23:24:23  fredo
-    added workaround for broken truetype naming-tables
-
-    Revision 1.13  2005/03/14 22:01:27  fredo
-    upd 2005
-
-    Revision 1.12  2005/01/21 10:00:43  fredo
-    added handling of nosubset option
-
-    Revision 1.11  2004/12/29 01:12:27  fredo
-    fixed no warn for recursion
-
-    Revision 1.10  2004/12/16 00:30:53  fredo
-    added no warn for recursion
-
-    Revision 1.9  2004/11/22 21:07:55  fredo
-    fixed multibyte-encoding support to work consistently acress cjk/ttf/otf
-
-    Revision 1.8  2004/11/22 02:25:05  fredo
-    added advanced attributes
-
-    Revision 1.7  2004/08/25 03:03:27  fredo
-    removed fuss
-
-    Revision 1.6  2004/06/15 09:14:52  fredo
-    removed cr+lf
-
-    Revision 1.5  2004/06/07 19:44:43  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.4  2004/04/20 09:46:25  fredo
-    added glyph->read fix for subset-vector
-
-    Revision 1.3  2003/12/08 13:06:01  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.2  2003/11/30 17:31:41  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.2  2003/11/30 16:57:02  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.1  2003/11/30 14:16:39  Administrator
-    added CVS id/log
-
-
-=cut
