@@ -1,8 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::courier;
 
-our $VERSION = '2.023'; # VERSION
+our $VERSION = '2.028'; # VERSION
 
-$FONTDATA = {
+use strict;
+use warnings;
+
+our $FONTDATA = {
     'fontname' => 'Courier',
     'type' => 'Type1',
     'apiname' => 'Cour',
